@@ -4,7 +4,7 @@
 #  SPDX-License-Identifier: Apache-2.0
 #
 
-from os import path,makedirs,getcwd, walk
+from os import path,makedirs,getcwd, walk, listdir,mkdir
 import logging
 import argparse
 import tarfile
@@ -16,15 +16,25 @@ import yaml
 from diadmin.vctl_cmds.login import di_login
 from diadmin.vctl_cmds.vrep import import_artifact, solution_to_repo
 
-VFLOW_PATHS = {'operators':'/files/vflow/subengines/com/sap/python36/operators/',
-               'pipelines':'/files/vflow/graphs/',
-               'dockerfiles':'/files/vflow/dockerfiles/'}
+VFLOW_PATHS = {'operators':'/files/vflow/subengines/com/sap/python36/',
+               'graphs':'/files/vflow/',
+               'dockerfiles':'/files/vflow/'}
 
 
-def make_tarfile(source_dir) :
-    tar_filename = path.join(path.dirname(source_dir),path.basename(source_dir) + '.tgz')
+def make_tarfile(artifact_type,source) :
+    if artifact_type == 'all' or artifact_type == '*' :
+        sources =  [('operators','operators'),('graphs','graphs'),('dockerfiles','dockerfiles')]
+    elif source == '.' or source == '*' :
+        sources = [(artifact_type,artifact_type)]
+    else :
+        sources =[(artifact_type,path.join(artifact_type,source))]
+    tar_filename = path.join(artifact_type,source + '.tgz')
     with tarfile.open(tar_filename, "w:gz") as tar:
-        tar.add(source_dir, arcname=path.basename(source_dir))
+        for s in sources :
+            for d in listdir(s[1]) :
+                sd = path.join(s[1],d)
+                if path.isdir(sd) :
+                    tar.add(sd)
     return tar_filename
 
 def main() :
@@ -33,9 +43,11 @@ def main() :
     #
     # command line args
     #
-    achoices = ['operators','pipelines','dockerfiles','bundle']
-    description =  "Uploads operators, pipelines, dockerfiles and bundle to SAP Data Intelligence.\nPre-requiste: vctl."
+    achoices = ['operators','graphs','dockerfiles','all','*']
+    description =  "Uploads operators, graphs, dockerfiles and bundle to SAP Data Intelligence.\nPre-requiste: vctl."
     parser = argparse.ArgumentParser(description=description)
+    parser.add_argument('-i','--init', help = 'Creates a config.yaml and the necessary folders. Additionally you need '
+                                              'to add \'* *\' as dummy positional arguments',action='store_true')
     parser.add_argument('-c','--config', help = 'Specifies yaml-config file',default='config_demo.yaml')
     parser.add_argument('-r','--conflict', help = 'Conflict handling flag of \'vctl vrep import\'')
     parser.add_argument('artifact_type', help='Type of artifacts. \'bundle\'- only supports .tgz-files with differnt artifact types.',choices=achoices)
@@ -47,6 +59,20 @@ def main() :
     parser.add_argument('-g', '--gitcommit', help='Git commit for the uploaded files',action='store_true')
     args = parser.parse_args()
 
+    if args.init :
+        logging.info('Creating config-file: config.yaml')
+        for f in  VFLOW_PATHS.keys() :
+            if not path.isdir(f) :
+                mkdir(f)
+        with open("config.yaml",'w') as file :
+            params = {'URL': 'https://vsystem.ingress.xxx.shoot.live.k8s-hana.ondemand.com',
+                      'TENANT' : 'default',
+                      'USER':'user',
+                      'PWD':'pwd123'}
+            yaml.dump(params,file)
+        return 0
+
+
     config_file = 'config.yaml'
     if args.config:
         config_file = args.config
@@ -69,15 +95,16 @@ def main() :
     if (re.match('.+\.tgz$',args.artifact) or re.match('.+\.tar.gz$',args.artifact)):
         import_artifact(args.artifact_type,args.artifact,user,conflict)
     else :
-        tf = make_tarfile(args.artifact)
+        tf = make_tarfile(args.artifact_type,args.artifact)
         import_artifact(args.artifact_type,tf,user,conflict)
 
     if args.solution:
-
         if re.match('.+\.tgz$',args.artifact):
             basename =  re.match('(.+)\.tgz$',args.artifact).group(0)
         elif re.match('.+\.tar.gz$',args.artifact) :
             basename = re.match('(.+)\.tar.gz$',args.artifact).group(0)
+        elif args.artifact == '*' or args.artifact == '.' :
+            basename = args.artifact_type
         else :
             basename = args.artifact
         basename = path.basename(basename)
@@ -88,7 +115,7 @@ def main() :
         folder = path.join(args.artifact_type,args.artifact)
         logging.info(f'Auto-commit for uploaded artifact: {folder}')
         run(['git','add',folder])
-        run(['git','commit','-m','didownload'])
+        run(['git','commit','-m','diupload'])
 
 
 if __name__ == '__main__':
